@@ -35,7 +35,7 @@ Dir.prototype.__proto__ = Base.prototype;
  * @param {String} dirname
  */
 Dir.prototype.create = function(dirname) {
-  return fs.mkdirSync(path.normalize(dirname), 0777);
+  return fs.mkdirSync(path.normalize(dirname), 0700); //0700 we can read,write and execute
 };
 
 /**
